@@ -20,7 +20,7 @@ use PHPUnit\Framework\TestCase;
  */
 abstract class AbstractIcuTest extends TestCase
 {
-    public function errorNameProvider()
+    public static function errorNameProvider()
     {
         return [
             [-129, '[BOGUS UErrorCode]'],
