@@ -76,7 +76,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         $this->assertIsIntlSuccess($formatter, $errorMessage, $errorCode);
     }
 
-    public function formatProvider()
+    public static function formatProvider()
     {
         $dateTime = new \DateTime('@0');
         $dateTimeImmutable = new \DateTimeImmutable('@0');
@@ -301,7 +301,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         $this->assertIsIntlFailure($formatter, $errorMessage, $errorCode);
     }
 
-    public function formatErrorProvider()
+    public static function formatErrorProvider()
     {
         return [
             ['y-M-d', 'foobar', 'datefmt_format: string \'foobar\' is not numeric, which would be required for it to be a valid date: U_ILLEGAL_ARGUMENT_ERROR'],
@@ -318,7 +318,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         $this->assertSame($expected, $formatter->format($timestamp));
     }
 
-    public function formatWithTimezoneProvider()
+    public static function formatWithTimezoneProvider()
     {
         $data = [
             [0, 'UTC', '1970-01-01 00:00:00'],
@@ -360,7 +360,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         $this->assertEquals($expected, $formatter->format(0));
     }
 
-    public function formatTimezoneProvider()
+    public static function formatTimezoneProvider()
     {
         return [
             ['z', 'GMT', 'GMT'],
@@ -510,7 +510,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         $this->assertSame($expected, $formatter->format($timestamp));
     }
 
-    public function dateAndTimeTypeProvider()
+    public static function dateAndTimeTypeProvider()
     {
         return [
             [0, IntlDateFormatter::FULL, IntlDateFormatter::NONE, 'Thursday, January 1, 1970'],
@@ -536,7 +536,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         $this->assertSame($expected, $formatter->format($datetime));
     }
 
-    public function relativeDateTypeProvider()
+    public static function relativeDateTypeProvider()
     {
         return [
             [0, IntlDateFormatter::RELATIVE_FULL, IntlDateFormatter::NONE, 'Thursday, January 1, 1970'],
@@ -604,32 +604,32 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         $this->assertIsIntlSuccess($formatter, $errorMessage, $errorCode);
     }
 
-    public function parseProvider()
+    public static function parseProvider()
     {
         return array_merge(
-            $this->parseYearProvider(),
-            $this->parseQuarterProvider(),
-            $this->parseMonthProvider(),
-            $this->parseStandaloneMonthProvider(),
-            $this->parseDayProvider(),
-            $this->parseDayOfWeekProvider(),
-            $this->parseDayOfYearProvider(),
-            $this->parseHour12ClockOneBasedProvider(),
-            $this->parseHour12ClockZeroBasedProvider(),
-            $this->parseHour24ClockOneBasedProvider(),
-            $this->parseHour24ClockZeroBasedProvider(),
-            $this->parseMinuteProvider(),
-            $this->parseSecondProvider(),
-            $this->parseTimezoneProvider(),
-            $this->parseAmPmProvider(),
-            $this->parseStandaloneAmPmProvider(),
-            $this->parseRegexMetaCharsProvider(),
-            $this->parseQuoteCharsProvider(),
-            $this->parseDashSlashProvider()
+            static::parseYearProvider(),
+            static::parseQuarterProvider(),
+            static::parseMonthProvider(),
+            static::parseStandaloneMonthProvider(),
+            static::parseDayProvider(),
+            static::parseDayOfWeekProvider(),
+            static::parseDayOfYearProvider(),
+            static::parseHour12ClockOneBasedProvider(),
+            static::parseHour12ClockZeroBasedProvider(),
+            static::parseHour24ClockOneBasedProvider(),
+            static::parseHour24ClockZeroBasedProvider(),
+            static::parseMinuteProvider(),
+            static::parseSecondProvider(),
+            static::parseTimezoneProvider(),
+            static::parseAmPmProvider(),
+            static::parseStandaloneAmPmProvider(),
+            static::parseRegexMetaCharsProvider(),
+            static::parseQuoteCharsProvider(),
+            static::parseDashSlashProvider()
         );
     }
 
-    public function parseYearProvider()
+    public static function parseYearProvider()
     {
         return [
             ['y-M-d', '1970-1-1', 0],
@@ -637,7 +637,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseQuarterProvider()
+    public static function parseQuarterProvider()
     {
         return [
             ['Q', '1', 0],
@@ -660,7 +660,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseMonthProvider()
+    public static function parseMonthProvider()
     {
         return [
             ['y-M-d', '1970-1-1', 0],
@@ -670,7 +670,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseStandaloneMonthProvider()
+    public static function parseStandaloneMonthProvider()
     {
         return [
             ['y-L-d', '1970-1-1', 0],
@@ -679,7 +679,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseDayProvider()
+    public static function parseDayProvider()
     {
         return [
             ['y-M-d', '1970-1-1', 0],
@@ -689,7 +689,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseDayOfWeekProvider()
+    public static function parseDayOfWeekProvider()
     {
         return [
             ['E', 'Thu', 0],
@@ -701,7 +701,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseDayOfYearProvider()
+    public static function parseDayOfYearProvider()
     {
         return [
             ['D', '1', 0],
@@ -709,7 +709,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseHour12ClockOneBasedProvider()
+    public static function parseHour12ClockOneBasedProvider()
     {
         return [
             // 12 hours (1-12)
@@ -734,7 +734,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseHour12ClockZeroBasedProvider()
+    public static function parseHour12ClockZeroBasedProvider()
     {
         return [
             // 12 hours (0-11)
@@ -759,7 +759,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseHour24ClockOneBasedProvider()
+    public static function parseHour24ClockOneBasedProvider()
     {
         return [
             // 24 hours (1-24)
@@ -786,7 +786,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseHour24ClockZeroBasedProvider()
+    public static function parseHour24ClockZeroBasedProvider()
     {
         return [
             // 24 hours (0-23)
@@ -813,7 +813,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseMinuteProvider()
+    public static function parseMinuteProvider()
     {
         return [
             ['y-M-d HH:m', '1970-1-1 0:1', 60],
@@ -821,7 +821,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseSecondProvider()
+    public static function parseSecondProvider()
     {
         return [
             ['y-M-d HH:mm:s', '1970-1-1 00:01:1', 61],
@@ -829,7 +829,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseTimezoneProvider()
+    public static function parseTimezoneProvider()
     {
         return [
             ['y-M-d HH:mm:ss zzzz', '1970-1-1 00:00:00 GMT-03:00', 10800],
@@ -845,7 +845,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseAmPmProvider()
+    public static function parseAmPmProvider()
     {
         return [
             // AM/PM (already covered by hours tests)
@@ -854,7 +854,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseStandaloneAmPmProvider()
+    public static function parseStandaloneAmPmProvider()
     {
         return [
             ['a', 'AM', 0],
@@ -862,7 +862,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseRegexMetaCharsProvider()
+    public static function parseRegexMetaCharsProvider()
     {
         return [
             // regexp meta chars in the pattern string
@@ -871,7 +871,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseQuoteCharsProvider()
+    public static function parseQuoteCharsProvider()
     {
         return [
             ["'M'", 'M', 0],
@@ -882,7 +882,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
-    public function parseDashSlashProvider()
+    public static function parseDashSlashProvider()
     {
         return [
             ['y-M-d', '1970/1/1', 0],
@@ -905,7 +905,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         $this->assertIsIntlFailure($formatter, $errorMessage, $errorCode);
     }
 
-    public function parseErrorProvider()
+    public static function parseErrorProvider()
     {
         return [
             // 1 char month
@@ -956,7 +956,7 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         $this->assertEquals($expectedTimeZoneId, $formatter->getTimeZoneId());
     }
 
-    public function setTimeZoneProvider()
+    public static function setTimeZoneProvider()
     {
         return [
             ['UTC', 'UTC'],
